program checkoutput

   use dal
   use errorhandling

   implicit none

   type(DataSetT) IIDataSetH
   type(ArrayT) IIArrayH
   real(kind=single), dimension(:,:), pointer :: image
   integer nDim
   integer(kind=int32), dimension(2) :: lb
   integer(kind=int32), dimension(2) :: ub
   real(kind=single), allocatable, dimension(:, :) :: tmp
   integer(kind=int32) allocErr
   real(kind=single) mean
   real(kind=single) variance
   real(kind=single) sd

   IIDataSetH = dataSet("corrimage.fits", read)
   IIArrayH = array(IIDataSetH, "PRIMARY",read)
   image => real32Array2Data(IIArrayH)

   nDim = numberofDimensions(IIArrayH)

   if (nDim /=2) then
      call error("notImage", "Data in PRIMARY array is not an image")
   end if

   lb = lbound(image)
   ub = ubound(image)

   allocate (tmp(lb(1):ub(1), lb(2):ub(2)), stat=allocErr)
   if (allocErr /= 0) then
      call fatal("allocError", "Can't allocate memory for internal array.")
   end if


   mean = real(sum(image)) / real(size(image))
   tmp = (image - mean)**2
   variance = real(sum(tmp)) / real((size(image)) - 1.0)
   sd = sqrt(variance)

   call release(IIArrayH)
   call release(IIDataSetH)

   write(*,*) sd

   if (sd .gt. 25.0) then
      call fatal("failed", "Standard deviation too large.")
   end if

end program
